@@ -10,10 +10,15 @@ from .aws_data_layers import (
     AWSLambdaLayer,
     ManagedAWSLambdaLayer,
     PrebuiltAWSLambdaLayer,
+    AWSBaseEMRLayer,
     AWSEMRLayer,
     ManagedAWSEMRLayer,
     PrebuiltAWSEMRLayer,
+    AWSEMRServerlessLayer,
+    ManagedAWSEMRServerlessLayer,
+    PrebuiltAWSEMRServerlessLayer,
     AWSRedshiftLayer,
     ManagedAWSRedshiftLayer,
     PrebuiltAWSRedshiftLayer,
+    AWSAthenaLayer,
 )
