@@ -1,4 +1,19 @@
 import os
+import sys
+
+import boto3
+
+import ADF
+
+
+def get_aws_region() -> str:
+    try:
+        region = boto3.session.Session().region_name or os.environ.get(
+            "AWS_DEFAULT_REGION", "eu-west-1"
+        )
+    except:
+        region = "eu-west-1"
+    return region
 
 
 class ADFGlobalConfig:
@@ -26,10 +41,8 @@ class ADFGlobalConfig:
     ]
 
     # AWS settings
-    AWS_REGION = os.environ.get("AWS_DEFAULT_REGION", "eu-west-3")
+    AWS_REGION = get_aws_region()
     AWS_PACKAGE_BUCKET = "adf-bucket-3d05fc66-0f12-11ec-8eee-9cb6d0dc2783"
-    AWS_EMR_PACKAGE_KEY = "public/zips/emr_package.zip"
-    AWS_LAMBDA_PACKAGE_KEY = "public/zips/lambda_package.zip"
 
     # Defaults
     BATCH_TIME_FORMAT_STRING = "%Y_%m_%d__%H_%M_%S"
@@ -41,3 +54,19 @@ class ADFGlobalConfig:
             cls.TIMESTAMP_COLUMN_NAME,
             cls.SQL_PK_COLUMN_NAME,
         ]
+
+    @classmethod
+    def get_artifact_prefix(cls) -> str:
+        return f"public/artifacts/v{ADF.__version__}/python{sys.version_info.major}.{sys.version_info.minor}/"
+
+    @classmethod
+    def get_adf_launcher_key(cls) -> str:
+        return f"{cls.get_artifact_prefix()}adf-launcher.py"
+
+    @classmethod
+    def get_emr_package_zip_key(cls) -> str:
+        return cls.get_artifact_prefix() + "zips/emr_package.zip"
+
+    @classmethod
+    def get_lambda_package_zip_key(cls) -> str:
+        return cls.get_artifact_prefix() + "zips/lambda_package.zip"
